﻿using System;
using System.Diagnostics;
using AppKit;
using Foundation;

namespace AssetImport
{
	public partial class ViewController : NSViewController
	{
		public ViewController(IntPtr handle) : base(handle)
		{
		}

		public override void ViewDidLoad()
		{
			base.ViewDidLoad();

			// Do any additional setup after loading the view.
		}

		public override NSObject RepresentedObject
		{
			get
			{
				return base.RepresentedObject;
			}
			set
			{
				base.RepresentedObject = value;
				// Update the view, if already loaded.
			}
		}

		partial void ClickedButton(Foundation.NSObject sender)
		{
			ClickedLabel.StringValue = ShowOpenPanel(sender);
		}

		[Export("openDocument:")]
		string ShowOpenPanel(NSObject sender)
		{
			string str = "";
			using (var panel = new NSOpenPanel())
			{
				// 複数選択の可否
				panel.AllowsMultipleSelection = false;
				// ファイル選択の可否
				panel.CanChooseFiles = true;
				// ディレクトリ選択の可否
				panel.CanChooseDirectories = false;
				// 受け入れるファイルタイプ
				// 拡張子のみ，ピリオドなし，複数指定可能
				panel.AllowedFileTypes = new[] { "fbx" };
				// 開くボタンのテキスト，指定しない場合はOS標準
				panel.Prompt = "開く";
				// モーダルウィンドウのタイトル
				panel.Title = "AssetImport";

				// モーダル表示
				var ret = panel.RunModal();

				// キャンセルが押された場合 0 が返る
				if (ret > 0)
					str = panel.Url.Path;
			}
			return str;
		}

		partial void ExportModel(Foundation.NSObject sender)
		{
			string str = string.Copy(ClickedLabel.StringValue);
			str = str.Replace(".fbx", ".mdl");
			NSString path = (NSString)NSBundle.MainBundle.BundlePath;
			string dir = path.DeleteLastPathComponent();
			Console.WriteLine(dir);
			Run(dir+"/AssetImporter", "model", ClickedLabel.StringValue, str);
		}

		partial void ExportAnimation(Foundation.NSObject sender)
		{
			string str = string.Copy(ClickedLabel.StringValue);
			str = str.Replace(".fbx", ".ani");
			NSString path = (NSString)NSBundle.MainBundle.BundlePath;
			string dir = path.DeleteLastPathComponent();
			Run(dir+"/AssetImporter", "anim", ClickedLabel.StringValue, str);
		}

		static string Run(string launchPath, params string[] launchArgs)
		{
			var r = string.Empty;

			try
			{
				var pipeOut = new NSPipe();

				var t = new NSTask();
				t.LaunchPath = launchPath;
				t.Arguments = launchArgs;
				t.StandardOutput = pipeOut;

				t.Launch();
				t.WaitUntilExit();
				t.Dispose();

				r = pipeOut.ReadHandle.ReadDataToEndOfFile().ToString();
			}
			catch (Exception ex)
			{
				Console.WriteLine("launchctl failed: " + ex);
			}
			return r;
		}
	}
}
